aboutsummaryrefslogtreecommitdiffstats
path: root/tap-rpcstat.c
diff options
context:
space:
mode:
Diffstat (limited to 'tap-rpcstat.c')
-rw-r--r--tap-rpcstat.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/tap-rpcstat.c b/tap-rpcstat.c
index d9799803cc..5ba75043a0 100644
--- a/tap-rpcstat.c
+++ b/tap-rpcstat.c
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply RTT statistics to twireshark.
* It is only used by twireshark and not wireshark
*
* It serves as an example on how to use the tap api.
*/
@@ -66,7 +66,7 @@ typedef struct _rpcstat_t {
/* This callback is never used by twireshark but it is here for completeness.
* When registering below, we could just have left this function as NULL.
*
* When used by wireshark, this function will be called whenever we would need
@@ -186,10 +186,10 @@ rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
return 1;
}
/* This callback is used when twireshark wants us to draw/update our
* data to the output device. Since this is twireshark only output is
* stdout.
* Twireshark will only call this callback once, which is when twireshark has
* finished reading all packets and exists.
* If used with wireshark this may be called any time, perhaps once every 3
* seconds or so.
@@ -268,7 +268,7 @@ rpcstat_find_procs(gpointer *key, gpointer *value _U_, gpointer *user_data _U_)
/* When called, this function will create a new instance of rpcstat.
* program and version are whick onc-rpc program/version we want to
* collect statistics for.
* This function is called from twireshark when it parses the -z rpc, arguments
* and it creates a new instance to store statistics in and registers this
* new instance for the rpc tap.
*/
@@ -289,7 +289,7 @@ rpcstat_init(const char *optarg, void* userdata _U_)
filter=NULL;
}
} else {
- fprintf(stderr, "twireshark: invalid \"-z rpc,rtt,<program>,<version>[,<filter>]\" argument\n");
+ fprintf(stderr, "tshark: invalid \"-z rpc,rtt,<program>,<version>[,<filter>]\" argument\n");
exit(1);
}
@@ -309,8 +309,8 @@ rpcstat_init(const char *optarg, void* userdata _U_)
rpc_max_proc=-1;
g_hash_table_foreach(rpc_procs, (GHFunc)rpcstat_find_procs, NULL);
if(rpc_min_proc==-1){
- fprintf(stderr,"twireshark: Invalid -z rpc,rrt,%d,%d\n",rpc_program,rpc_version);
- fprintf(stderr," Program:%d version:%d isn't supported by twireshark.\n", rpc_program, rpc_version);
+ fprintf(stderr,"tshark: Invalid -z rpc,rrt,%d,%d\n",rpc_program,rpc_version);
+ fprintf(stderr," Program:%d version:%d isn't supported by tshark.\n", rpc_program, rpc_version);
exit(1);
}
@@ -345,7 +345,7 @@ rpcstat_init(const char *optarg, void* userdata _U_)
g_free(rs->filter);
g_free(rs);
- fprintf(stderr, "twireshark: Couldn't register rpc,rtt tap: %s\n",
+ fprintf(stderr, "tshark: Couldn't register rpc,rtt tap: %s\n",
error_string->str);
g_string_free(error_string, TRUE);
exit(1);
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply RTT statistics to twireshark.
- * It is only used by twireshark and not wireshark
+/* This module provides rpc call/reply RTT statistics to tshark.
+ * It is only used by tshark and not wireshark
*
* It serves as an example on how to use the tap api.
@@ -66,7 +66,7 @@ typedef struct _rpcstat_t {
*/
-/* This callback is never used by twireshark but it is here for completeness.
+/* This callback is never used by tshark but it is here for completeness.
* When registering below, we could just have left this function as NULL.
*
@@ -186,10 +186,10 @@ rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
return 1;
}
-/* This callback is used when twireshark wants us to draw/update our
- * data to the output device. Since this is twireshark only output is
+/* This callback is used when tshark wants us to draw/update our
+ * data to the output device. Since this is tshark only output is
* stdout.
@@ -186,10 +186,10 @@ rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
* stdout.
- * Twireshark will only call this callback once, which is when twireshark has
+ * TShark will only call this callback once, which is when tshark has
* finished reading all packets and exists.
* If used with wireshark this may be called any time, perhaps once every 3
@@ -268,7 +268,7 @@ rpcstat_find_procs(gpointer *key, gpointer *value _U_, gpointer *user_data _U_)
* program and version are whick onc-rpc program/version we want to
* collect statistics for.
- * This function is called from twireshark when it parses the -z rpc, arguments
+ * This function is called from tshark when it parses the -z rpc, arguments
* and it creates a new instance to store statistics in and registers this
* new instance for the rpc tap.